==> tabular-data-gwt-service-2.2.0-20140625.133905-105-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/codelisthelper/CodelistMappingSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.codelisthelper;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.resource.ResourceTD;
import org.gcube.portlets.user.td.gwtservice.shared.source.Source;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

public class CodelistMappingSession implements Serializable {

	private static final long serialVersionUID = 2381185326076784908L;

	protected TRId trId;
	protected Source source;
	protected ResourceTD resourceTD;
	protected String url;
	protected String localFileName;
	protected String itemId;

	public TRId getTrId() {
		return trId;
	}

	public void setTrId(TRId trId) {
		this.trId = trId;
	}

	public String getLocalFileName() {
		return localFileName;
	}

	public void setLocalFileName(String localFileName) {
		this.localFileName = localFileName;
	}

	public String getItemId() {
		return itemId;
	}

	public void setItemId(String itemId) {
		this.itemId = itemId;
	}

	public Source getSource() {
		return source;
	}

	public void setSource(Source source) {
		this.source = source;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public ResourceTD getResourceTD() {
		return resourceTD;
	}

	public void setResourceTD(ResourceTD resourceTD) {
		this.resourceTD = resourceTD;
	}

	@Override
	public String toString() {
		return "CodelistMappingSession [trId=" + trId + ", source=" + source
				+ ", url=" + url + ", localFileName=" + localFileName
				+ ", itemId=" + itemId + "]";
	}

}

==> tabular-data-gwt-service-2.3.0-20140905.164112-245-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/codelisthelper/CodelistMappingSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.codelisthelper;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.resource.ResourceTD;
import org.gcube.portlets.user.td.gwtservice.shared.source.Source;
import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

public class CodelistMappingSession implements Serializable {

	private static final long serialVersionUID = 2381185326076784908L;

	protected TRId trId;
	protected Source source;
	protected ResourceTD resourceTD;
	protected String url;
	protected String localFileName;
	protected String itemId;
	protected TabResource connectedTR;
	protected ColumnData connectedColumn;
	
	public TRId getTrId() {
		return trId;
	}

	public void setTrId(TRId trId) {
		this.trId = trId;
	}

	public String getLocalFileName() {
		return localFileName;
	}

	public void setLocalFileName(String localFileName) {
		this.localFileName = localFileName;
	}

	public String getItemId() {
		return itemId;
	}

	public void setItemId(String itemId) {
		this.itemId = itemId;
	}

	public Source getSource() {
		return source;
	}

	public void setSource(Source source) {
		this.source = source;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public ResourceTD getResourceTD() {
		return resourceTD;
	}

	public void setResourceTD(ResourceTD resourceTD) {
		this.resourceTD = resourceTD;
	}

	public TabResource getConnectedTR() {
		return connectedTR;
	}

	public void setConnectedTR(TabResource connectedTR) {
		this.connectedTR = connectedTR;
	}

	public ColumnData getConnectedColumn() {
		return connectedColumn;
	}

	public void setConnectedColumn(ColumnData connectedColumn) {
		this.connectedColumn = connectedColumn;
	}

	@Override
	public String toString() {
		return "CodelistMappingSession [trId=" + trId + ", source=" + source
				+ ", resourceTD=" + resourceTD + ", url=" + url
				+ ", localFileName=" + localFileName + ", itemId=" + itemId
				+ ", connectedTR=" + connectedTR + ", connectedColumn="
				+ connectedColumn + "]";
	}

	

}
